#
# spec file for package libextractor
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname	        3
%define common_soname   1
Name:           libextractor
Version:        1.13
Release:        1.4
Summary:        Library to Extract Metadata from Files
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://www.gnu.org/software/libextractor/
Source:         https://ftp.gnu.org/gnu/libextractor/libextractor-%{version}.tar.gz
Source2:        https://ftp.gnu.org/gnu/libextractor/libextractor-%{version}.tar.gz.sig
Source3:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=libextractor&download=1#/%{name}.keyring
Source4:        %{name}-rpmlintrc
Recommends:     %{name}-plugins
%lang_package
# SECTION general dependencies
BuildRequires:  c++_compiler
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libapparmor)
BuildRequires:  pkgconfig(zlib)
# /SECTION
# SECTION file format dependencies
# Unfortunately OBS cannot parse this from macros, so this is repeated in
# subpackages
BuildRequires:  giflib-devel
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmpeg2)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(vorbis)
%if 0%{?suse_version} > 1600
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(tidy)
%else
BuildRequires:  file-devel
BuildRequires:  libtidy-devel
%endif
# /SECTION

%description
GNU Libextractor is a library for extracting meta data from various files types.

The '%{name}' package contains the 'extract' command. Install '%{name}-plugins'
to install all available file format plugins, or select individual packages
from '%{name}-plugins*' as needed.

# Macro that generates a plugin package definition
%define pluginpkg(B:) \
%package plugins-%{1} \
Summary:         The '%{1}' libextractor plugin \
Supplements:     %{name}-plugins = %{version} \
BuildRequires:   %{-B*} \
\
%description plugins-%{1} \
This package ships the '%{1}' plugin for libextractor. \
\
%files plugins-%{1} \
%%license COPYING \
%{_libdir}/%{name}/%{name}_%{1}.so \
%{nil}
#
# These packages are split out for the following reasons:
# 0. Give the user control over which file formats to parse. Media format
#    libraries are notorious for security issues, especially when parsing
#    content from potentially untrusted sources.
# 1. Give the user the option for a reduced dependency installation.
%pluginpkg archive      -B pkgconfig(libarchive)
%pluginpkg exiv2        -B pkgconfig(exiv2)
%pluginpkg flac         -B pkgconfig(flac)
%pluginpkg gif          -B giflib-devel
%pluginpkg gstreamer    -B pkgconfig(gstreamer-plugins-base-1.0)
%pluginpkg jpeg         -B pkgconfig(libjpeg)
%pluginpkg mpeg         -B pkgconfig(libmpeg2)
%pluginpkg ogg          -B pkgconfig(vorbis)
%pluginpkg ole2         -B pkgconfig(libgsf-1)
%pluginpkg rpm          -B pkgconfig(rpm)
%pluginpkg thumbnailgtk -B pkgconfig(gdk-pixbuf-2.0)
%pluginpkg tiff         -B pkgconfig(libtiff-4)
%if 0%{?suse_version} > 1600
%pluginpkg mime         -B pkgconfig(libmagic)
%pluginpkg html         -B pkgconfig(tidy)
%else
%pluginpkg mime         -B file-devel
%pluginpkg html         -B libtidy-devel
%endif

%package -n %{name}%{soname}
Summary:        Shared libraries for libextractor
Recommends:     %{name}-plugins

%description -n %{name}%{soname}
GNU Libextractor is a library for extracting meta data from various files types.

This package contains the shared libraries for %{name}.

%package -n     %{name}_common%{common_soname}
Summary:        Shared libraries (common) for libextractor

%description -n %{name}_common%{common_soname}
GNU Libextractor is a library for extracting meta data from various files types.

This package contains the shared libraries for %{name}.

%package        plugins
Summary:        Installs all plugins for %{name}
Requires:       %{name}-plugins-archive = %{version}
Requires:       %{name}-plugins-base = %{version}
Requires:       %{name}-plugins-exiv2 = %{version}
Requires:       %{name}-plugins-flac = %{version}
Requires:       %{name}-plugins-gif = %{version}
Requires:       %{name}-plugins-gstreamer = %{version}
Requires:       %{name}-plugins-html = %{version}
Requires:       %{name}-plugins-jpeg = %{version}
Requires:       %{name}-plugins-mime = %{version}
Requires:       %{name}-plugins-mpeg = %{version}
Requires:       %{name}-plugins-ogg = %{version}
Requires:       %{name}-plugins-ole2 = %{version}
Requires:       %{name}-plugins-rpm = %{version}
Requires:       %{name}-plugins-thumbnailgtk = %{version}
Requires:       %{name}-plugins-tiff = %{version}
BuildArch:      noarch

%description    plugins
GNU Libextractor is a library for extracting meta data from various files types.

This package triggers the installation of all available file format plugins.

%package        plugins-base
Summary:        Base pugins for %{name}

%description    plugins-base
GNU Libextractor is a library for extracting meta data from various files types.

This package contains file format plugins for %{name} that do not add extra
dependencies.

%package devel
Summary:        Include Files and Libraries mandatory for Development with libextractor
Group:          Development/Languages/C and C++
Requires:       %{name}%{soname} = %{version}
Requires:       %{name}_common%{common_soname} = %{version}

%description devel
GNU Libextractor is a library for extracting meta data from various files types.

This package contains all necessary include files and libraries needed to
develop applications that require these.

%prep
%autosetup -p1

%build
%configure \
    --disable-static

%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# generate a list of plugins that do not introduce additional dependencies
for i in %{buildroot}%{_libdir}/%{name}/*.so; do
    readelf -a "$i" | \
    sed '/(NEEDED)/s!.*\[\(.*\)\].*!\1!p;d' | {
        target=base
        fname=${i##%{buildroot}}
        while read lib; do
            lib=${lib%%.so*}
            case $lib in
                (libgcc_s|ld-linux*)                ;;
                (libz|libdl)                        ;;
                (libextractor|libextractor_common)  ;;
                (libc|libm|libpthread)              ;;
                (libstdc++)                         ;;
                (*)
                    target=other
                    echo "$fname -> $lib"
                    ;;
            esac
        done
        case $target in
            (base)    echo "$fname" >> filelists.base;;
        esac
    }
done
%find_lang %{name}

%check
# failing: text_exiv2
# flakey: test_ipc
# export LD_LIBRARY_PATH=%%{buildroot}%%{_libdir}
# export LIBEXTRACTOR_PREFIX=%%{buildroot}%%{_libdir}/libextractor
# %%make_build check

%ldconfig_scriptlets -n %{name}%{soname}
%ldconfig_scriptlets -n %{name}_common%{common_soname}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_bindir}/extract
%{_mandir}/man1/extract.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%files plugins
%license COPYING

%files plugins-base -f filelists.base
%license COPYING

%files -n %{name}%{soname}
%license COPYING
%{_libdir}/libextractor.so.%{soname}
%{_libdir}/libextractor.so.%{soname}.*
%dir %{_libdir}/%{name}

%files -n %{name}_common%{common_soname}
%license COPYING
%{_libdir}/%{name}_common.so.%{common_soname}
%{_libdir}/%{name}_common.so.%{common_soname}.*

%files devel
%license COPYING
%{_includedir}/*.h
%{_libdir}/%{name}.so
%{_libdir}/%{name}_common.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man?/libextractor.?%{ext_man}
%{_infodir}/%{name}.info%{?ext_info}

%changelog
* Mon Apr  1 2024 Andreas Stieger <andreas.stieger@gmx.de>
- split file format plugins into individual packages for user
  control, dependency limitation and security reasons
- remove unneeded build dependencies
- update license to GPL 2 and 3 or later
- enable apparmor support
- drop libextractor-1.7-segfault.patch
* Sat Mar 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- fix libextractor-lang not installable, move to extract-lang
* Sun Dec 17 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.13:
  * Misc. fixes to build system and code to support more recent libexiv2.
  * Revive REAL plugin
  * Revive ELF plugin
  * Removing plugins depending on buggy, unstable libffmpeg library
- drop libextractor-1.11-exiv2-0.28.patch, upstream
* Sun Oct 15 2023 seife+obs@b1-systems.com
- update to version 1.11:
  * mask SIGPIPE to avoid test case failure with latest librpm
    (#6709)
  * fix test case failures (#6613)
  * fixed some code that called deprecated libav routines
  * fixed missing initialization of duration in Opus extractor
  * fix invalid read for malformed DVI files (#5846)
  * fix build issue with exiv2-0.27 (#5820)
  * consistently use AS_IF and AS_CASE in configure.ac
- remove obsolete libextractor-1.8-exiv2-0.27.patch
- reformat libextractor-1.7-segfault.patch so it applies again
- add libextractor-1.11-exiv2-0.28.patch for new exiv2-0.28 APIs
* Wed May 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Build with mpeg2
- Add libextractor-1.8-exiv2-0.27.patch
* Wed Feb 20 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.9:
  * translation updates
  * Fix possible out-of-bounds read in libextractor_common in case
    of iconv() failure
  * Fix NULL dereference in OLE2 extractor (for malformed input)
  * do not export non-public functions from API
- includes changes from 1.8:
  * Fix missing 0-terminator on corrupted ZIP files
* Sun Jul 29 2018 aloisio@gmx.com
- Added libextractor-1.7-segfault.patch to fix segfault during
  build
* Sat Jul 14 2018 astieger@suse.com
- update to 1.7:
  * Fix potential infinite loop in mpeg extractor.
  * Fix build issue with FFmpeg 4.0
  * Fixing length calculation error in unzip logic reported
  * Fixing NULL pointer issues in GIF, IT, NSFE, S3M, SID and XM
    plugins, caused (except for GIF) by signed/unsigned confusion.
  * Fix integer overflows in DVI extractor
* Mon Oct 16 2017 astieger@suse.com
- update to 1.6:
  * Fix various issues, including security relevant code fixes
  * build with -std=c99 to fix build
* Thu Oct 12 2017 astieger@suse.com
- update to 1.5
- add upstream signing key and verify source signature
- various spec file fixes for distribution standards
* Mon Aug 14 2017 avvissu@yandex.by
- Update to stable 1.4
- Remove _service file
* Fri Jun  2 2017 avvissu@yandex.by
- Update to version 1.3+rsv37257:
  * tolerate apparmor errors if not supported by Kernel
  * trying to fix #4055
  * updated French translation
  * fix path detection for -ltdl check
  * simple hack for PDF support
  * fixing #4167 (untested)
  * trying to fix #4436
  * doxygen fixes
- Add _service file
- Spec file cleanup
* Thu Jun 25 2015 avvissu@yandex.ru
- Update to 1.3
- Drop: libextractor-1.2_giflib-5.1.0.patch
- Add %%BUILD_ORIG macro to build in Packman
- Add BuildRequires: pkgconfig(gstreamer-plugins-base-1.0)
- Use pkgconfig in package names
- Add package for plugins
- Add %%info_{add,del} macro
- Spec file cleanup
* Thu May 28 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2 (libextractor-1.2_giflib-5.1.0.patch)
* Thu Dec 19 2013 sleep_walker@suse.cz
- bump to 1.2
  * Increase select() timeout, handle timeout case better.
  * Required external installation of libltdl.
  * Check for presence of tidyNodeGetValue in libtidy.
  * Updated Dutch translation.
  * Fix build with libavcodec >= 54.25.0.
- removing libextractor-ffmpeg-2.0.patch as it is not needed anymore
* Sat Jul 27 2013 i@margueirte.su
- update version 1.1
  * xpdf plugin obsoleted
  * qt thumbnail plugin obsoleted
  * applefile plugin obsoleted
  * asf plugin obsoleted
  * elf plugin obsoleted
  * flv plugin obsoleted
  * mkv plugin obsoleted
  * mp3 plugin obsoleted (thus all the id3 plugins)
  * real plugin obsoleted
  * tar plugin obsoleted
  * see http://lists.gnu.org/archive/html/gnunet-svn/2012-08/msg00217.html
- html plugin disabled, 'coz we don't have htmltidy.
- jpeg plugin doesn't work for lower versions. (< 1230)
- gstreamer plugin disabled, 'coz it's experimental.
* Thu May 31 2012 Manfred.Tremmel@iiv.de
- ffmpeg calls are outdated, compile against ffmpeg_oldabi
* Thu Dec  1 2011 pascal.bleser@opensuse.org
- update to 0.6.3
- This release fixes various minor bugs, in particular better handling of
  malloc failures and more robust handling of malformed inputs in various
  plugins.
* Sun Mar 14 2010 toni@links2linux.de
- update to 0.6.1
- This release fixes a problem with LE not finding its plugins under
  certain conditions. It also fixes an IPC issue under FreeBSD which
  caused some plugins to not work.
* Thu Jan 14 2010 toni@links2linux.de
- update to 0.6.0
- new so-name ==> libextractor3
- renamed libextractor to extractor
- removed static library
- This release adds out-of-process execution for plugins and improves
  the quality and quantity of the extracted meta data for many formats.
- It breaks API compatibility.
* Tue Oct 20 2009 toni@links2linux.de
- update to 0.5.23
- This release adds support for librpm 4.7 and uses an external version of
  libexiv2 for improved and more up-to-date EXIV2 support.
* Sat Feb 21 2009 toni@links2linux.de
- update to 0.5.22
- added install-info macros, moved info pages to devel package
* Sun Nov  2 2008 toni@links2linux.de
- update to 0.5.21
* Tue Jul 15 2008 toni@links2linux.de
- update to 0.5.20c
* Sun Apr 27 2008 toni@links2linux.de
- update to 0.5.20b
* Tue Apr 15 2008 toni@links2linux.de
- update to 0.5.20a
* Sun Mar 23 2008 toni@links2linux.de
- update to 0.5.20
* Sun Jan 13 2008 toni@links2linux.de
- update to 0.5.19a
* Mon Jan  7 2008 toni@links2linux.de
- update to 0.5.19
* Sun Sep  2 2007 toni@links2linux.de
- buildOpenSUSE-10.3, fixed BuildRequires
* Mon Jun 25 2007 toni@links2linux.de
- initial build 0.5.18
